track 1.1.0
===========

Copyright 2011 EPFL BBCF <webmaster.bbcf@epfl.ch>

track is a python module for reading and writing genomic data.

It was developed by the Bioinformatics and Biostatistics Core
Facility (BBCF) at the EPFL.

track is released under the GNU General Public License 3.0. A copy
of this license is in the LICENSE.txt file.

Full documentation
==================

The full documentation can be found [on our website](http://bbcf.epfl.ch/track).
